% Stochastic Growth Model
% _____________________________________
%
% One Persistent shock is introduced in order to study 
% the dynamic behavior of the model
%
% A 1 per cent shock (z) to total factor productivity a
% 

var y k c l w r a cy;
varexo z;

parameters alpha delta n g rho lam1 lam2 lam3 new eta;

alpha=0.333;
delta=0.03;
n=0.01;
g=0.02;
rho=0.02;
lam1=(1+rho+g)/(1+g);
lam2=((1-alpha)*(rho+g+delta))/(alpha*(1+g));
lam3=((1-alpha)*(rho+g+delta))/(1+rho+g);
new=(2/3)/((1/3)-alpha*(2/3));
eta=0.9;

model;

c=c(+1)-lam3*eta*a-lam3*l(+1)+lam3*(lam1*k+lam2*a+(1-lam1-lam2)*c+lam2*l);
k=lam1*k(-1)+lam2*a(-1)+(1-lam1-lam2)*c(-1)+lam2*l(-1);
a=eta*a(-1)+z;
l=new*((alpha*k)-c+(1-alpha)*a);
y=alpha*k+(1-alpha)*(l+a);
r=lam3*(a+l-k);
w=alpha*(k-l)+(1-alpha)*a;
cy=c-y;

end;

initval;

z=0;

end;

steady;

endval;

z=0;

end;

steady;
check;

shocks;
var z;
periods 1:1;
values 0.01;
end;

simul(periods=100);

subplot(6,1,1); plot(y(1:80,1)); title('Output');
subplot(6,1,2); plot(c(1:80,1)); title('Consumption');
subplot(6,1,3); plot(l(1:80,1)); title('Employment');
subplot(6,1,4); plot(k(1:80,1)); title('Capital Stock');
subplot(6,1,5); plot(r(1:80,1)); title('Real Interest Rate');
subplot(6,1,6); plot(w(1:80,1)); title('Real Wage');
