% Dynamic Phillips Curve Model
% Based on Insiders and Outsiders
%
% We Investigate the Effects of Two Shocks
%
% A. A Temporary Monetary Shock
%
% B. A Persistent Productivity Shock
%
var y pi r i wp u a;
varexo ea ei;
parameters alpha lamda rho theta phi1 phi2 eta psi1 psi2 psi3;

alpha=0.333;
lamda=0.500;
rho=0.02;
theta=1;
phi1=1.5;
phi2=0.5;
eta=0.75;
psi1=(phi2+theta*(1-lamda)*(1-alpha))/(phi1*alpha+phi2+theta*(1-lamda)*(1-alpha));
psi2=((phi1-lamda)/phi1)*(alpha/(phi1*alpha+phi2+theta*(1-lamda)*(1-alpha)));
psi3=lamda/phi1;

model;

y=(1-lamda)*a+lamda*y(-1)+((1-alpha)/alpha)*((1-psi1)*ea-psi2*ei);
u=(1-lamda)*0.05+lamda*u(-1)-(1/alpha)*((1-psi1)*ea-psi2*ei);
wp=a+alpha*lamda*(u(-1)-0.05)-((1-psi1)*ea-psi2*ei);
r=rho-(theta*(1-eta)*a)+(theta*(1-alpha)*(1-lamda)*(u-0.05));
a=eta*a(-1)+ea;
i=rho-theta*(1-eta)*a+0.02+phi1*(pi-0.02)-phi2*(u-0.05)+ei;
pi=(1-lamda)*0.02+lamda*pi(-1)-psi1*ea-psi2*ei+psi3*ei(-1);

end;

initval;

y=0;
pi=0.02;
u=0;
r=0.02;
i=0.04;
wp=0;
u=0.05;
a=0;
ea=0;
ei=0;

end;

steady;

endval;

y=0;
pi=0.02;
u=0;
r=0.02;
i=0.04;
wp=0;
u=0.05;
a=0;
ea=0;
ei=0.0;

end;

steady;

shocks;

var ea;
periods 1:1;
values 0.01;

end;

check;

steady;

simul(periods=20);

% Plotting Inflation Unemployment Output Interest Rates Real Wage

subplot(3,2,1); plot(pi(1:15,1)); title('Inflation');
subplot(3,2,2); plot(u(1:15,1)); title('Unemployment');
subplot(3,2,3); plot(y(1:15,1)); title('Output');
subplot(3,2,4); plot(i(1:15,1)); title('Nominal Interest Rate');
subplot(3,2,5); plot(r(1:15,1)); title('Real Interest Rate');
subplot(3,2,6); plot(wp(1:15,1)); title('Real Wage');



