% Equilibrium Unemployment Model
% Based on Matching Frictions
%
% We investigate three shocks
%
% A. A doubling of the job separation rate from 0.025 t0 0.05, which implies that le rises from 0 to 0.025
% B. A rise in the replacement rate rho from 0.5 to 0.7, which implies ze rises from 0 to 0.2
% C. A doubling of the real interest rate r from 0.03 to 0.06, which implies xe rises from 0 to 0.03

var theta v u q w z uper vper;
varexo xe me ze le ce;

parameters lamda m mi p c r beta rho;

lamda=0.025;
m=1/2;
mi=1/2;
p=1.0;
c=1/2;
r=0.03;
beta=0.5;
rho=0.5;

model;

theta=(w*(1-(1-beta)*(rho+ze))-beta*p)/(beta*(c+ce)*p);
w=p-(((r+xe)+(lamda+le))*(c+ce)*p)/((m+me)*(theta^(-mi)));
q=(m+me)*(theta^(-mi));
z=(rho+ze)*w;
u=(lamda+le)+(1-(lamda+le)-(theta*q))*u(-1);
v=theta*u(-1);
uper=u*100;
vper=v*100;

end;

initval;

theta=1;
u=0.04;
v=0.04;
q=0.01;
w=0.97;
ze=0.0;
ce=0;
me=0.0;
xe=0;
le=0;
uper=4;
vper=4;

end;

steady;

endval;

theta=1;
u=0.04;
v=0.04;
q=0.01;
w=0.97;
ze=0.0;
ce=0.0;
me=0.0;
xe=0.03;
le=0.0;
uper=4;
vper=4;

end;

steady;

shocks;

var ce;
periods 0:1;
values 0.0;

end;

check;

steady;

simul(periods=125);

subplot(1,2,1); plot(uper(1:20,1)); title('Unemployment Rate');
subplot(1,2,2); plot(vper(1:20,1)); title('Vacancy Rate');
