% Blancard Weil Model in discrete time
% _____________________________________
%
% Three fiscal shocks are introduced in order to study 
% the dynamic behavior of the model
%
% 1. A tax financed increase in primary government expenditure cg by 0.01
% 2. A debt financed increase in in primary government expenditure cg by 0.01
% 3. A cut in autonomous taxes tavc by 0.01 (cut in autonomous taxes)
%
% The original debt to GDP ratio is assumed to be equal to 0.3 

var y k c w r s gy cg d tav cgy tavy dy def dexo defexo;
varexo a x z cgc tavc;

parameters alpha delta n g rho psi;

alpha=0.333;
delta=0.03;
n=0.01;
g=0.02;
rho=0.02;
psi=0.075;

model;

y=a*(k(-1)^alpha);
r=(alpha*a*k(-1)^(alpha-1))-delta;
c(+1)=(((((1+r)/(1+(rho*x)))*(1/(1+g)))*c)
-((n*z*rho*x)/((1+rho*x)*(1+n*z)*(1+g)))*(k+d));
k=(1/((1+n*z)*(1+g)))*((y-c-cg)+(1-delta)*k(-1));
w=(1-alpha)*a*k(-1)^(alpha);
cg=cgc;
d=((1+r)/((1+g)*(1+n)))*d(-1)+cg-tav;
def=r*d(-1)+cg-tav;
tav=tavc+psi*d(-1);
s=(y-c-cg)/y;
gy=(y-y(-1))/y(-1);
cgy=cg/y;
tavy=tav/y;
dy=d/y;
dexo=0.791779;
defexo=0.0241951;

end;

initval;

k=5.3;
c=1.38;
y=1.7;
a=1;
r=0.075;
w=1.16;
x=1;
z=1;
cgc=0.5;
tavc=0.45;
d=0.791779;
dexo=0.791779;
defexo=0.0241951;

end;

steady;

endval;

k=5.3;
c=1.38;
y=1.7;
a=1.0;
r=0.075;
w=1.16;
x=1.0;
z=1;
cgc=0.5;
d=0.791779;
tavc=0.45-0.05;
dexo=0.791779;
defexo=0.0241951;

end;

steady;
check;

simul(periods=100);

% Plotting Capital Output Consumption Real Interest Rate Real Wage Savings
% Rate Taxes Primary Government Expenditure Government Debt

subplot(5,2,1); plot(k(1:80,1)); title('Capital');
subplot(5,2,2); plot(y(1:80,1)); title('Output');
subplot(5,2,3); plot(c(1:80,1)); title('Consumption');
subplot(5,2,4); plot(w(1:80,1)); title('Real Wage');
subplot(5,2,5); plot(r(1:80,1)); title('Real Interest Rate');
subplot(5,2,6); plot(s(1:80,1)); title('Savings Rate');
subplot(5,2,7); plot(tav(1:80,1)); title('Taxes');
subplot(5,2,8); plot(cg(1:80,1)); title('Primary Government Expenditure');
subplot(5,2,9); plot(d(1:80,1)); title('Government Debt');
subplot(5,2,10); plot(def(1:80,1)); title('Government Deficit');
