% Ramsey Model with Distortionary Taxation in discrete time
% _____________________________________
%
% We study an increase in the tax rate on income from capital tk
% and an increase in the tax rate on business profits tf
% 
% 1. The tax rate tk is increased from 0 to 10%
% 2. The tax rate tf is increased from 0 to 10%
% 

var y k c w r s gy;
varexo a x z tk tf;

parameters alpha delta n g rho theta;

alpha=0.333;
delta=0.03;
n=0.01;
g=0.02;
rho=0.02;
theta=1;

model;

y=a*(k(-1)^alpha);
r=(1-tf)*((alpha*a*k(-1)^(alpha-1))-delta);
c(+1)=((((1+(r*(1-tk)))/(1+(rho*x)))^(1/theta))*(1/(1+g)))*c;
k=(1/((1+n*z)*(1+g)))*((y-c)+(1-delta)*k(-1));
w=(1-alpha)*a*k(-1)^(alpha);
s=(y-c)/y;
gy=(y-y(-1))/y(-1);

end;

initval;

k=5.3;
c=1.38;
y=1.7;
a=1;
r=0.075;
w=1.16;
x=1;
z=1;
tf=0;
tk=0;

end;

steady;

endval;

k=5.3;
c=1.38;
y=1.7;
a=1;
r=0.075;
w=1.16;
x=1.00;
z=1;
tf=0.10;
tk=0.0;

end;

steady;
check;

simul(periods=100);

% Plotting Capital Output Consumption Real Interest Rate Real Wage Savings
% Rate

subplot(3,2,1); plot(k(1:80,1)); title('Capital');
subplot(3,2,2); plot(y(1:80,1)); title('Output');
subplot(3,2,3); plot(c(1:80,1)); title('Consumption');
subplot(3,2,4); plot(w(1:80,1)); title('Real Wage');
subplot(3,2,5); plot(r(1:80,1)); title('Real Interest Rate');
subplot(3,2,6); plot(s(1:80,1)); title('Savings Rate');

