% Blancard Weil Model with Money in discrete time
% _____________________________________
%
% We introduce an increase in the rate of growth of the money supply mi
% from 5% to 10%
%
% Taxes are adjusted continuously to keep government debt constant at 0.5
% 

var y k c w r s gy cg d tav cgy tavy dy m i pi inftax;
varexo a x z cgc mi dc;

parameters alpha delta n g rho psi gamma;

alpha=0.333;
delta=0.03;
n=0.01;
g=0.02;
rho=0.02;
psi=0.075;
gamma=0.975;

model;

y=a*(k(-1)^alpha);
r=(alpha*a*k(-1)^(alpha-1))-delta;
i=r+pi;
pi=mi-n-g-((c(+1)/c)-1)+((i(+1)/i)-1);
c(+1)=(((((1+r)/(1+(rho*x)))*(1/(1+g)))*c)
-((n*z*rho*x*gamma)/((1+rho*x)*(1+n*z)*(1+g)))*(k+d+m));
m=((1-gamma)/gamma)*(c/i);
k=(1/((1+n*z)*(1+g)))*((y-c-cg)+(1-delta)*k(-1));
w=(1-alpha)*a*k(-1)^(alpha);
cg=cgc;
d=dc;
tav=cg+(r-n-g)*d-mi*m;
s=100*(y-c-cg)/y;
gy=(y-y(-1))/y(-1);
cgy=100*cg/y;
tavy=100*tav/y;
dy=100*d/y;
inftax=mi*m;

end;

initval;

k=5.3;
c=1.38;
y=1.7;
a=1;
r=0.075;
w=1.16;
x=1;
z=1;
cgc=0.5;
dc=0.5;
mi=0.05;
pi=0.02;
i=0.06;

end;

steady;

endval;

k=5.3;
c=1.38;
y=1.7;
a=1.0;
r=0.075;
w=1.16;
x=1.0;
z=1;
cgc=0.5+0.0;
dc=0.5;
mi=0.10;
pi=0.02;
i=0.06;

end;

steady;
check;

simul(periods=100);

% Plotting Capital Output Consumption etc

subplot(5,2,1); plot(k(1:80,1)); title('Capital Stock');
subplot(5,2,2); plot(y(1:80,1)); title('Output');
subplot(5,2,3); plot(c(1:80,1)); title('Consumption');
subplot(5,2,4); plot(r(1:80,1)); title('Real Interest Rate');
subplot(5,2,5); plot(w(1:80,1)); title('Real Wage');
subplot(5,2,6); plot(s(1:80,1)); title('Savings Rate');
subplot(5,2,7); plot(pi(1:80,1)); title('Inflation');
subplot(5,2,8); plot(i(1:80,1)); title('Nominal Interest Rate');
subplot(5,2,9); plot(m(1:80,1)); title('Real Money Balances');
subplot(5,2,10); plot(inftax(1:80,1)); title('Inflation Tax');
